function hdrdisp(hdr, evs)
% function hdrdisp(hdr, evs)
% displays a HDR image and enables to inspect it across EVS log2
% scales, using a slider.
    
if nargin ~= 2
    error('hdrdisp must be called with exactly 2 arguments'); 
end

if ~strcmp(class(hdr),'double') 
    error('HDR must be of type double'); 
end

if ndims(hdr)~=3
   error('HDR must be 3-dimensional array'); 
end

if size(hdr,3)~=3
    error(['HDR must be an RGB image, thus its 3rd dimensions must ' ...
           'have size 3']);
end

if prod(size(evs))~=1
    error('EVS must be scalar')
end

if ~strcmp(class(hdr),'double')
    error('EVS must be of class double')
end
    

figure; set(gcf, 'Toolbar', 'figure');
max_value = max(hdr(:)); 
log_max_value = log2(max_value);
log_min_value = log_max_value - evs;

uicontrol('Style', 'slider',...
          'Min',log_min_value,'Max',log_max_value,'Value',log_max_value,...
          'Units', 'Normalized',...
          'Position', [0.1 0 0.8 0.05],...
          'Callback', {@mycallback, hdr});  


image(mat2gray(hdr, [0 max_value])); 
title(sprintf('LOG2(max value displayed)=%1.1f', log_max_value))
axis equal off

end


function mycallback(hObj,event,hdr) 
    value = get(hObj,'Value');
    set(get(gca,'child'),'CData', mat2gray(hdr, [0 2^value]))
    title(sprintf('LOG2(max value displayed)=%1.1f', value))

end

